#  ::: enzax.mcmc
    options:
      show_root_heading: true
      filters:
        - "!check"
      members:
        - ObservationSet
        - PriorSet
        - run_nuts
        - posterior_logdensity_amm
        - get_idata
        - ind_prior_from_truth
        - ind_normal_prior_logdensity
